@@ -342,19 +342,6 @@ def cli_qa_describe(obj, qa_hash, json):
     QA("describe", obj["project"], obj["config"], obj["tokens"], flags).run()
 
 
-@main.command(
-    "secret", help="Manage secrets grants in multiple countries (aws-vault needed)"
-)
-@click.option("-c", "--create", "create_action", required=False, count=True)
-@click.option("-g", "--grant", "grant_action", required=False, count=True)
-@click.option("-b", "--base-profile", "base_profile", required=False)
-@click.pass_obj
-def cli_secret(obj, create_action, grant_action, base_profile):
-    Secret(
-        obj["project"], obj["config"], create_action, grant_action, base_profile
-    ).run()
-
-
 @qa.command(
     "toggle-maintenance",
     help="Toggle maintenance mode (requires 'manage:maintenance' permission)",
@@ -362,3 +349,24 @@ def cli_secret(obj, create_action, grant_action, base_profile):
 @click.pass_obj
 def cli_qa_toggle_maintenance(obj):
     QA("toggle-maintenance", obj["project"], obj["config"], obj["tokens"]).run()
+
+
+@main.group(
+    "secret", help="Manage secrets grants in multiple countries (aws-vault needed)"
+)
+def secret():
+    pass
+
+
+@secret.command("create", help="Create a new secret")
+@click.option("-b", "--base-profile", "base_profile", required=False)
+@click.pass_obj
+def cli_secret_create(obj, base_profile):
+    Secret(obj["project"], obj["config"], "create", base_profile).run()
+
+
+@secret.command("grant", help="Grant permissions to an existing secret")
+@click.option("-b", "--base-profile", "base_profile", required=False)
+@click.pass_obj
+def cli_secret_grant(obj, base_profile):
+    Secret(obj["project"], obj["config"], "grant", base_profile).run()
