@@ -61,7 +61,9 @@ class AskReview:
             logger.info(
                 f"Moving the {youtrack_id} card for review on youtrack and adding user tags"
             )
-            self._youtrack.update_state(youtrack_id, "Review")
+            self._youtrack.update_state(
+                youtrack_id, self._config.youtrack["review_state"]
+            )
             for rev in youtrack_reviewers:
                 try:
                     self._youtrack.add_tag(youtrack_id, f"review:{rev}")
