@@ -109,7 +109,7 @@ class QainitHandler:
 
     def list(self, params, page=1, page_size=10):
         filters = []
-        status_values = '"created","creating","updated","updating","failed","frozen"'
+        status_values = '"created","creating","updated","updating","failed","frozen","freezing","unfreezing"'
         if len(params["status"]) > 0:
             status_values = ",".join([f'"{status}"' for status in params["status"]])
         filters.append(f"status=[{status_values}]")
