@@ -3,7 +3,7 @@ import re
 import time
 from urllib.parse import urljoin
 
-from requests_toolbelt.sessions import BaseUrlSession
+from suite_py.lib.requests.session import Session
 from suite_py.lib.requests.auth import BearerAuth
 
 REGEX = r"([A-Za-z]+-[0-9]+)"
@@ -14,7 +14,7 @@ class YoutrackHandler:
         headers = {"Accept": "application/json", "Content-Type": "application/json"}
         self._base_url = config.youtrack["url"] + "/"
         self._issue_url = urljoin(self._base_url, "issue/")
-        self._client = BaseUrlSession(base_url=urljoin(self._base_url, "api/"))
+        self._client = Session(base_url=urljoin(self._base_url, "api/"))
         self._client.headers = headers
         self._client.auth = BearerAuth(tokens.youtrack)
 
@@ -22,6 +22,10 @@ class YoutrackHandler:
         params = {"fields": "id,name,shortName"}
         return self._client.get("admin/projects", params=params).json()
 
+    def get_current_user(self):
+        params = {"fields": "login"}
+        return self._client.get("users/me", params=params).json()
+
     def get_issue(self, issue_id):
         params = {
             "fields": "$type,id,idReadable,summary,customFields(name,value(name))"
